# Opengate-data

Opengate-data is a python library that helps you easily integrate OpenGate into your python projects.

## Installation

pip install opengate-data

## Import

from opengate_data import OpenGateClient

## Basic Use with user and password

client = OpenGateClient(url="Url", user="User", password="Password")

## Basic Use with api-key

client = OpenGateClient(url="Url", api_key="Api_Key")

## Additional Documentation

For more details and examples, please refer to the [complete documentation](https://documentation.opengate.es/).

